from barbell2.utils import get_tag_pixels


class Tag2Numpy:

    def __init__(self, tag_file_path, shape=None):
        self.tag_file_path = tag_file_path
        self.npy_array = None
        self.shape = shape

    def execute(self):
        self.npy_array = get_tag_pixels(self.tag_file_path)
        if self.shape is not None:
            self.npy_array = self.npy_array.reshape(self.shape)
        return self.npy_array



import os
import shutil
import pydicom
import pydicom.errors
import argparse

from barbell2.utils import get_tag_file_for_dicom


def get_variable_operator_value(vc):
    if '==' in vc:
        items = [x.strip() for x in vc.split('==')]
        return items[0], '==', items[1]
    if '>=' in vc:
        items = [x.strip() for x in vc.split('>=')]
        return items[0], '>=', items[1]
    if '<=' in vc:
        items = [x.strip() for x in vc.split('<=')]
        return items[0], '<=', items[1]
    if '>' in vc:
        items = [x.strip() for x in vc.split('>')]
        return items[0], '>', items[1]
    if '<' in vc:
        items = [x.strip() for x in vc.split('<==>')]
        return items[0], '<', items[1]
    raise RuntimeError(f'Illegal value constraint: {vc}')


def dicom_ok(p, args):
    attributes = [x.strip() for x in args.attributes.split(',')]
    for attribute in attributes:
        if attribute not in p:
            return False, f'Attribute {attribute} missing'
    value_constraints = [x.strip() for x in args.values.split(',')]
    for vc in value_constraints:
        var, op, val = get_variable_operator_value(vc)
        val_p = str(p[var].value)
        if op == '==':
            if val_p != val:
                return False, f'Attribute {var} != {val} ({val_p})'
        if op == '<=':
            if val_p > val:
                return False, f'Attribute {var} > {val} ({val_p})'
        if op == '>=':
            if val_p < val:
                return False, f'Attribute {var} < {val} ({val_p})'
        if op == '<':
            if val_p >= val:
                return False, f'Attribute {var} >= {val} ({val_p})'
        if op == '>':
            if val_p <= val:
                return False, f'Attribute {var} <= {val} ({val_p})'
    return True, None


def main():
    """ This script filters a directory with DICOM files (and possible TAG files) checking
    the headers for mandatory information, like rows, columns, pixel spacing, etc. It's
    important that TAG files are also copied whenever a DICOM file is ok.
    """
    parser = argparse.ArgumentParser()
    parser.add_argument('--input_dir', help='Input directory', default='.')
    parser.add_argument('--output_dir', help='Output directory', default='output')
    parser.add_argument(
        '--attributes', help='Attributes that must be present',
        default='Rows,Columns,PixelSpacing,BitsStored,BitsAllocated,RescaleSlope,RescaleIntercept')
    parser.add_argument(
        '--values', help='Value constraints', default='Rows==512,Columns==512,BitsStored>=12,BitsStored<=16')
    args = parser.parse_args()
    os.makedirs(args.output_dir)
    errors = []
    for f in os.listdir(args.input_dir):
        f_path = os.path.join(args.input_dir, f)
        f_path_new = os.path.join(args.output_dir, f)
        try:
            p = pydicom.dcmread(f_path, stop_before_pixels=True)
            result, msg = dicom_ok(p, args)
            if result:
                # Copy DICOM and TAG file to output directory
                shutil.copy(f_path, f_path_new)
                tag_file = get_tag_file_for_dicom(f_path)
                if os.path.isfile(tag_file):
                    tag_name = os.path.split(tag_file)[1]
                    shutil.copy(tag_file, os.path.join(args.output_dir, tag_name))
                    print(f'{f_path}|*.tag')
                else:
                    print(f'{f_path}')
            else:
                errors.append(f'{f_path}: {msg}')
        except pydicom.errors.InvalidDicomError:
            pass
    if len(errors) > 0:
        with open(os.path.join(args.output_dir, 'errors.txt'), 'w') as f:
            for error in errors:
                f.write(error + '\n')
        print('Errors encountered. See <output_dir>/errors.txt for details')
    else:
        print('No errors')


if __name__ == '__main__':
    from barbell2 import common
    common.setup_args_env([
        '--input_dir=/Users/Ralph/SURF Drive/projects/hpb/bodycomposition/data/l3tag_cohorts/SURG-PANC',
        '--output_dir=/Users/Ralph/Desktop/output',
    ])
    main()

# parser.add_argument(
#     '--mandatory_values', help='Values attributes must have', default='Rows=512,Columns=512')
# args = parser.parse_args()
# mandatory_attributes = [x.strip() for x in args.mandatory_attributes.split(',')]
# mandatory_values = [x.strip() for x in args.mandatory_values.split(',')]
# mandatory_values_dict = {}
# for value in mandatory_values:
#     items = [x.strip() for x in value.split('=')]
#     mandatory_values_dict[items[0]] = items[1]
# os.makedirs(args.output_dir)
# os.makedirs(args.output_dir_error)
# files_ok = []
# files_error = []
# for f in os.listdir(args.input_dir):
#     f_path = os.path.join(args.input_dir, f)
#     try:
#         error = False
#         p = pydicom.dcmread(f_path, stop_before_pixels=True)
#         for attribute in mandatory_attributes:
#             if attribute not in p:
#                 error = True
#                 files_error.append(f_path)
#                 print(f'Attribute {attribute} not in {f_path}')
#         for k, v in mandatory_values_dict.items():
#             v_p = str(p[k].value)
#             if v_p != v:
#                 error = True
#                 files_error.append(f_path)
#                 print(f'Value {v_p} of {k} should be {v}')
#         if not error:
#             files_ok.append(f_path)
#     except pydicom.errors.InvalidDicomError:
#         pass
# for f in files_ok:
#     shutil.copy(f, os.path.join(args.output_dir_error, os.path.split(f)[1]))
#     shutil.copy(f, os.path.join(args.output_dir, os.path.split(f)[1]))
# for f in files_error:



import argparse
import os
import shutil


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--input_dir', help='Input directory', default='.')
    parser.add_argument('--output_dir', help='Output directory', default='output')
    args = parser.parse_args()
    os.makedirs(args.output_dir)
    for root, dirs, files in os.walk(args.input_dir):
        for f_name in files:
            f_path = os.path.join(root, f_name)
            # Remove common root directory of each file's path
            f_name_new = f_path.replace(args.input_dir, '')[1:]
            # Replace slashes by underscores to build a new file name that's always unique
            f_name_new = f_name_new.replace(os.path.sep, '_')
            shutil.copy(f_path, os.path.join(args.output_dir, f_name_new))
            print(f_name_new)


if __name__ == '__main__':
    from barbell2 import common
    common.setup_args_env([
        '--input_dir=/Users/Ralph/data/surfdrive/projects/hpb/bodycomposition/data/l3tag_cohorts',
        '--output_dir=/Users/Ralph/Desktop/output',
    ])
    main()



import os
import shutil
import pydicom
import pydicom.errors
import argparse


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--input_dir', help='Input directory', default='.')
    parser.add_argument('--output_dir', help='Output directory', default='output')
    args = parser.parse_args()
    os.makedirs(args.output_dir)
    for f in os.listdir(args.input_dir):
        f_path = os.path.join(args.input_dir, f)
        f_path_new = os.path.join(args.output_dir, f)
        try:
            p = pydicom.dcmread(f_path)
            p.decompress()
            p.save_as(f_path_new)
            print(f_path_new)
        except pydicom.errors.InvalidDicomError:
            # Non-DICOM files are copied by default
            shutil.copy(f_path, f_path_new)


if __name__ == '__main__':
    from barbell2 import common
    common.setup_args_env([
        '--input_dir=/Users/Ralph/data/surfdrive/projects/hpb/bodycomposition/data/l3tag_cohorts/SURG-PANC',
        '--output_dir=/Users/Ralph/Desktop/output',
    ])
    main()



#!/usr/bin/env python

import os

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'pydicom',
    'numpy',
    'matplotlib',
    'pandas',
    'openpyxl',
    'nibabel',
    'pyside6',
    'pyopengl',
    'pygame',
    'PyInstaller',
    'pynrrd',
    'oauthlib',
    'requests-oauthlib',
]

setup_requirements = []

test_requirements = []

setup(
    author="Ralph Brecheisen",
    author_email='ralph.brecheisen@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Collection of Python libraries and tools",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='barbell2',
    name='barbell2',
    packages=find_packages(include=['barbell2', 'barbell2.*']),
    setup_requires=setup_requirements,
    entry_points={
        'console_scripts': [
            'bodycomp-adddcmext=barbell2.bodycomp.adddcmext:main',
            'bodycomp-decompdcm=barbell2.bodycomp.decompdcm:main',
            'bodycomp-flattendirs=barbell2.bodycomp.flattendirs:main',
            'bodycomp-copyfiles=barbell2.bodycomp.copyfiles:main',
            'castor-buildimport=barbell2.castor.buildimport:main',
        ],
    },
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/rbrecheisen/barbell2',
    version=os.environ['VERSION'],
    zip_safe=False,
)



import pandas as pd
from barbell2.castor import data


class CastorExportFileLoader:

    def __init__(self, file_path):
        self.file_path = file_path
        self.data = None

    def load(self):
        print('Loading Castor data...')
        df = pd.read_excel(self.file_path, dtype=str, engine='openpyxl', sheet_name='Study results')
        print('Loading Castor data dictionary...')
        df_dict = pd.read_excel(self.file_path, dtype=str, engine='openpyxl', sheet_name='Study variable list')
        self.data = data.CastorData(df, df_dict)
        return self.data


class DicaExportFileLoader:

    def __init__(self, file_path_data, file_path_dict):
        self.file_path_data = file_path_data
        self.file_path_dict = file_path_dict
        self.audit = None
        if 'dpca' in self.file_path_data:
            self.audit = 'DPCA'
        if 'dhba' in self.file_path_data:
            self.audit = 'DHBA'
        self.data = None

    def load(self):
        if self.file_path_data.endswith('.xls'):
            raise RuntimeError('Data must be recent Excel format (*.xlsx)')
        if self.file_path_dict.endswith('.xls'):
            raise RuntimeError('Data dictionary must be recent format (*.xlsx)')
        print(f'Loading {self.audit} data...')
        df_pat = pd.read_excel(self.file_path_data, dtype=str, sheet_name='patient', engine='openpyxl', index_col='uri')
        df_trt = pd.read_excel(self.file_path_data, dtype=str, sheet_name='verrichting', engine='openpyxl', index_col='uri')
        df_com = pd.read_excel(self.file_path_data, dtype=str, sheet_name='comorbiditeiten', engine='openpyxl', index_col='uri')
        print(f'Loading {self.audit} data dictionary...')
        df_dict_pat = pd.read_excel(self.file_path_dict, dtype=str, sheet_name='patient', engine='openpyxl')
        df_dict_trt = pd.read_excel(self.file_path_dict, dtype=str, sheet_name='verrichting', engine='openpyxl')
        df_dict_com = pd.read_excel(self.file_path_dict, dtype=str, sheet_name='comorbiditeiten', engine='openpyxl')
        if self.audit == 'DPCA':
            self.data = data.DpcaData(df_pat, df_trt, df_com, df_dict_pat, df_dict_trt, df_dict_com)
        if self.audit == 'DHBA':
            self.data = data.DhbaData(df_pat, df_trt, df_com, df_dict_pat, df_dict_trt, df_dict_com)
        return self.data
